![CI](https://github.com/ywatanabe1989/mngs/actions/workflows/pip_install.yml/badge.svg)

## Installation
``` bash
$ pip install mngs
```
or
``` bash
$ pip install git+https://github.com/ywatanabe1989/mngs.git@develop
```


## [`tree.txt`](./tree.txt)

``` bash
$ tree ./src/mngs > tree.txt
```
